@@ -1,5 +1,5 @@
 # Python 3 SDK for the KUSANAGI(tm) framework (http://kusanagi.io)
-# Copyright (c) 2016-2021 KUSANAGI S.L. All rights reserved.
+# Copyright (c) 2016-2022 KUSANAGI S.L. All rights reserved.
 #
 # Distributed under the MIT license.
 #
@@ -593,7 +593,7 @@ class Action(Api):
         try:
             # NOTE: The transport set to the call won't have any data added by the action component
             return_value, transport = client.call(
-                schema.get_address(),
+                self._state.values.get_component_address(),
                 self.get_action_name(),
                 [service, version, action],
                 timeout,
